local assets =
{
    Asset("ANIM", "anim/catcoonden2.zip"),
}

local prefabs =
{
    "catcoon",
    "log",
    "rope",
    "twigs",
    "collapse_small",
	"catcoonden_item",
	"silk",
	"houndstooth",
}

local loots =
{
    {'twigs',   1.00},
    {'rope',    0.05},
    {'boneshard', 0.2},
    {'feather', 0.05},
    {'feather_robin', 0.05},
    {'feather_robin_winter', 0.05},
    {'crow', 0.02},
    {'robin', 0.02},
    {'robin_winter', 0.02},
    {'rabbit', 0.02},
    {'mole', 0.02},
    {'smallmeat', 0.3},
}

local MAX_LIVES = 9

local function onhammered(inst)
    if inst.components.childspawner ~= nil then
        inst.components.childspawner:ReleaseAllChildren()
    end
    local x, y, z = inst.Transform:GetWorldPosition()
    inst.components.lootdropper:DropLoot(Vector3(x, y, z))
    local fx = SpawnPrefab("collapse_small")
    fx.Transform:SetPosition(x, y, z)
    fx:SetMaterial("wood")
    inst:Remove()
end

local function onhit(inst)
    if not inst.playing_dead_anim then
        inst.AnimState:PlayAnimation("hit", false)
    end
end

local function onbuilt(inst)
        inst.AnimState:PlayAnimation("building")
        inst.AnimState:PushAnimation("idle")             
    end

local function OnEntityWake(inst)
    if inst.lives_left <= 0 and inst.delay_end <= GetTime() then
        inst.lives_left = MAX_LIVES
        if inst.components.childspawner ~= nil then
            inst.components.childspawner:SetMaxChildren(1)
            inst.components.childspawner:StartRegen()
            inst.components.childspawner:StartSpawning()
        end
    end
    if inst.playing_dead_anim then
        if inst.lives_left > 0 then
            inst.playing_dead_anim = nil
            inst.AnimState:PlayAnimation("idle")
        end
    elseif inst.lives_left <= 0 then
        inst.playing_dead_anim = true
        inst.AnimState:PlayAnimation("dead", true)
    end
end

local function OnEntitySleep(inst)
end

local function onsave(inst, data)
    if inst.lives_left > 0 then
        data.lives = inst.lives_left
    elseif inst.delay_end > GetTime() then
        data.delay_remaining = inst.delay_end - GetTime()
    end
end

local function onload(inst, data)
    if data ~= nil then
        if data.lives_left ~= nil and data.lives_left > 0 then
            if inst.lives_left <= 0 and inst.components.childspawner ~= nil then
                inst.components.childspawner:SetMaxChildren(1)
                inst.components.childspawner:StartRegen()
                inst.components.childspawner:StartSpawning()
            end
            inst.lives_left = data.lives_left
            inst.delay_end = 0
        else
            if inst.lives_left > 0 and inst.components.childspawner ~= nil then
                if #inst.components.childspawner.childrenoutside > 0 then
                    for i, v in pairs(inst.components.childspawner.childrenoutside) do
                        v:Remove()
                    end
                end
                inst.components.childspawner:StopRegen()
                inst.components.childspawner:StopSpawning()
                inst.components.childspawner:SetMaxChildren(0)
            end
            inst.lives_left = 0
            inst.delay_end = GetTime() + (data.delay_remaining or 0)
        end
        if inst.playing_dead_anim then
            if inst.lives_left > 0 then
                inst.playing_dead_anim = nil
                inst.AnimState:PlayAnimation("idle")
            end
        elseif inst.lives_left <= 0 then
            inst.playing_dead_anim = true
            inst.AnimState:PlayAnimation("dead", true)
        end
    end
end

local function tulasanityget(inst, observer)
	observer = inst.components.sanityaura.observer
	if observer and observer.prefab == "tula" then
	inst.components.sanityaura.aura = TUNING.SANITYAURA_TINY*0.25
	inst.components.sanityaura:GetAura("tula")
	end
end

local function dig_up(inst, chopper)
		if inst.lives_left == 9 and inst.components.childspawner.numchildrenoutside == 0 then
            inst.components.lootdropper:SpawnLootPrefab("catcoonden_item9")
		elseif	inst.lives_left == 9 and inst.components.childspawner.numchildrenoutside > 0 then
            inst.components.lootdropper:SpawnLootPrefab("catcoonden_item8")
		
		elseif inst.lives_left == 8 and inst.components.childspawner.numchildrenoutside == 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item8")
		elseif inst.lives_left == 8 and inst.components.childspawner.numchildrenoutside > 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item7")
			
		elseif inst.lives_left == 7 and inst.components.childspawner.numchildrenoutside == 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item7")
		elseif inst.lives_left == 7 and inst.components.childspawner.numchildrenoutside > 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item6")
			
		elseif inst.lives_left == 6 and inst.components.childspawner.numchildrenoutside == 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item6")
		elseif inst.lives_left == 6 and inst.components.childspawner.numchildrenoutside > 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item5")
			
		elseif inst.lives_left == 5 and inst.components.childspawner.numchildrenoutside == 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item5")
		elseif inst.lives_left == 5 and inst.components.childspawner.numchildrenoutside > 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item4")
			
		elseif inst.lives_left == 4 and inst.components.childspawner.numchildrenoutside == 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item4")
		elseif inst.lives_left == 4 and inst.components.childspawner.numchildrenoutside > 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item3")
			
		elseif inst.lives_left == 3 and inst.components.childspawner.numchildrenoutside == 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item3")
		elseif inst.lives_left == 3 and inst.components.childspawner.numchildrenoutside > 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item2")
			
		elseif inst.lives_left == 2 and inst.components.childspawner.numchildrenoutside == 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item2")
		elseif inst.lives_left == 2 and inst.components.childspawner.numchildrenoutside > 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item1")
			
		elseif inst.lives_left == 1 and inst.components.childspawner.numchildrenoutside == 0 then
			inst.components.lootdropper:SpawnLootPrefab("catcoonden_item1")
		elseif inst.lives_left == 1 and inst.components.childspawner.numchildrenoutside > 0 then
			inst.components.lootdropper:SpawnLootPrefab("log")
			inst.components.lootdropper:SpawnLootPrefab("log")
			inst.components.lootdropper:SpawnLootPrefab("log")
			inst.components.lootdropper:SpawnLootPrefab("silk")
			inst.components.lootdropper:SpawnLootPrefab("houndstooth")
			
        else
            inst.components.lootdropper:SpawnLootPrefab("log")
			inst.components.lootdropper:SpawnLootPrefab("log")
			inst.components.lootdropper:SpawnLootPrefab("log")
			inst.components.lootdropper:SpawnLootPrefab("silk")
			inst.components.lootdropper:SpawnLootPrefab("houndstooth")
		end
			inst:Remove() 
		end

local function fn()
	local inst = CreateEntity()
    local trans = inst.entity:AddTransform()
	local anim = inst.entity:AddAnimState()
	local soundemitter = inst.entity:AddSoundEmitter()

    MakeObstaclePhysics(inst, .5)

    local minimap = inst.entity:AddMiniMapEntity()
	minimap:SetIcon( "catcoonden.png" )

    inst.AnimState:SetBank("catcoonden2")
    inst.AnimState:SetBuild("catcoonden2")
    inst.AnimState:PlayAnimation("idle")

    inst:AddTag("structure")
    inst:AddTag("chewable") -- by werebeaver
    inst:AddTag("catcoonden")

    MakeSnowCovered(inst)

    -------------------
	-------------------
	inst:ListenForEvent("onbuilt", onbuilt)
    -------------------
    inst:AddComponent("childspawner")
    inst.components.childspawner.childname = "catcoon"
    inst.components.childspawner:SetRegenPeriod(TUNING.CATCOONDEN_REGEN_TIME)
    inst.components.childspawner:SetSpawnPeriod(TUNING.CATCOONDEN_RELEASE_TIME)
    inst.components.childspawner:SetMaxChildren(1)
    inst.components.childspawner.canspawnfn = function(inst)
        if GetSeasonManager() and GetSeasonManager():IsRaining() then
            return false
        end
    end
    inst.components.childspawner:StartSpawning()

    inst.playing_dead_anim = nil
    inst.delay_end = 0
    inst.lives_left = MAX_LIVES
	
    inst.components.childspawner.onchildkilledfn = function(inst, child)
        inst.lives_left = inst.lives_left - 1
        if inst.lives_left <= 0 then
            inst.components.childspawner:StopRegen()
            inst.components.childspawner:StopSpawning()
            inst:RemoveComponent("childspawner")
        end
    end

    ---------------------
    inst:AddComponent("lootdropper")
    for i, v in ipairs(loots) do
        inst.components.lootdropper:AddRandomLoot(unpack(v))
    end
    inst.components.lootdropper.numrandomloot = 4

    MakeMediumBurnable(inst)
    MakeSmallPropagator(inst)

    ---------------------
    inst:AddComponent("inspectable")
    inst.components.inspectable.getstatus = function(inst, viewer)
        if inst.lives_left <= 0 then
            return "EMPTY"
        end
    end

	inst:AddComponent("sanityaura")
    inst.components.sanityaura.aura = TUNING.SANITYAURA_TINY*0.5
	inst.components.sanityaura:GetAura("tula")
	
	inst:AddComponent("workable")
    inst.components.workable:SetWorkAction(ACTIONS.DIG)
    inst.components.workable:SetOnFinishCallback(dig_up)
    inst.components.workable:SetWorkLeft(1)
	
    MakeSnowCovered(inst)

    inst.OnEntitySleep = OnEntitySleep
    inst.OnEntityWake = OnEntityWake

    inst.OnSave = onsave
    inst.OnLoad = onload

    return inst
end

STRINGS.NAMES.CATCOONDEN2 = "Hollow Stump"
STRINGS.RECIPE_DESC.CATCOONDEN2 = "A home for your fellow cat!"

STRINGS.CHARACTERS.GENERIC.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "It's a den in a stump.",
		EMPTY = "Its owner ran out of lives.",
	}

STRINGS.CHARACTERS.WILLOW.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "I wouldn't burn it while someone lives here.",
		EMPTY = "It's all dried up and ready for burning.",
	}

STRINGS.CHARACTERS.WOLFGANG.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "Stump is suspicious.",
		EMPTY = "Wolfgang more comfortable now that stump is empty.",
	}

STRINGS.CHARACTERS.WENDY.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "I could curl up and die in there.",
		EMPTY = "All cats must die.",
	}

STRINGS.CHARACTERS.WX78.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "LIFE LOOP ITERATING",
		EMPTY = "LIFE LOOP ENDED",
	}

STRINGS.CHARACTERS.WICKERBOTTOM.DESCRIBE.CATCOONDEN2 = 
    {
        GENERIC = "An excellent hollow for a den.",
        EMPTY = "Looks used up.",
    }

STRINGS.CHARACTERS.WOODIE.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "Ugh, how many more lives do you have?",
		EMPTY = "Good riddance.",
	}

STRINGS.CHARACTERS.WAXWELL.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "Vermin housing.",
		EMPTY = "Well, I guess that's that.",
	}

STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "Cute meat lives there.",
		EMPTY = "She fought bravely. Alas, she is gone.",
	}

STRINGS.CHARACTERS.WEBBER.DESCRIBE.CATCOONDEN2 = 
	{
		GENERIC = "Trunk house.",
		EMPTY = "The nine lives thing is true!",
	}

return Prefab("common/objects/catcoonden2", fn, assets, prefabs),
	MakePlacer( "common/catcoonden2_placer", "catcoonden2", "catcoonden2", "idle" ) 
