local assets =
{
	-- Animation files used for the item.
	Asset("ANIM", "anim/catcoonstaff.zip"),
	Asset("ANIM", "anim/swap_catcoonstaff.zip"),

	-- Inventory image and atlas file used for the item.
    Asset("ATLAS", "images/inventoryimages/catcoonstaff.xml"),
    Asset("IMAGE", "images/inventoryimages/catcoonstaff.tex"),
}

local function onfinished(inst)
    inst.SoundEmitter:PlaySound("dontstarve/common/gem_shatter")
    inst:Remove()
end

local function onequip(inst, owner) 
    owner.AnimState:OverrideSymbol("swap_object", -- Symbol to override.
    	"swap_catcoonstaff", -- Animation bank we will use to overwrite the symbol.
    	"swap_catcoonstaff") -- Symbol to overwrite it with.
    owner.AnimState:Show("ARM_carry") 
    owner.AnimState:Hide("ARM_normal") 
	
	if owner and owner.prefab == "tula" then
	inst.components.equippable.dapperness = TUNING.DAPPERNESS_TINY * 0.5
	end
end

local function onunequip(inst, owner) 
    owner.AnimState:Hide("ARM_carry") 
    owner.AnimState:Show("ARM_normal") 
	
	if owner and owner.prefab == "tula" then
	inst.components.equippable.dapperness = 0
	end
end

local function init()
	local inst = CreateEntity()
    local trans = inst.entity:AddTransform()
	local anim = inst.entity:AddAnimState()
	local soundemitter = inst.entity:AddSoundEmitter()

    MakeInventoryPhysics(inst)

    inst.AnimState:SetBank("catcoonstaff")
    inst.AnimState:SetBuild("catcoonstaff")
    inst.AnimState:PlayAnimation("catcoonstaff")

    inst:AddTag("staff")

	local minimap = inst.entity:AddMiniMapEntity()
	minimap:SetIcon("catcoonstaff.tex")
	
	
	local function catcoonstaff(staff)
	    local caster = inst.components.inventoryitem.owner
	    local pt = Vector3(caster.Transform:GetWorldPosition())
		 staff.components.finiteuses:Use(1) 
	
    local range = 30
    local ents = TheSim:FindEntities(pt.x, pt.y, pt.z, range)
	
	-- if not Tula, then sanity drain
	if caster.prefab ~= "tula" and caster.components.sanity then
		caster.components.sanity:DoDelta(-5)
	end
	
    for k, v in pairs(ents) do
        if v.prefab == "catcoon" and not v.components.follower.leader and caster.components.leader and not caster:HasTag("monster") 
		or v.prefab == "catcoon" and v.components.follower.leader == caster and caster.components.leader and not caster:HasTag("monster") then
			if v.components.sleeper:IsAsleep() then
				v.components.sleeper:WakeUp()
			end
			if not v.sg:HasStateTag("busy") then 
				v:FacePoint(caster.Transform:GetWorldPosition())
				v.sg:GoToState("idle") 
			end
			v.SoundEmitter:PlaySound("dontstarve/common/makeFriend")
			caster.components.leader:AddFollower(v)
			
			-- is caster Tula?
			if caster.prefab == "tula" then
			v.hairball_friend_interval = ( (TUNING.CATCOON_LOYALTY_PER_ITEM)*5 )
            v.components.follower:AddLoyaltyTime( (TUNING.CATCOON_LOYALTY_PER_ITEM)*5 )
			
			v.components.locomotor.walkspeed = 5
			v.components.health.absorb = 0.20
			v.components.combat:SetDefaultDamage((TUNING.CATCOON_DAMAGE)+9)
			v.components.combat:SetAttackPeriod((TUNING.CATCOON_ATTACK_PERIOD)*0.75)
			else
			v.hairball_friend_interval = ( (TUNING.CATCOON_LOYALTY_PER_ITEM)*2.5 )
            v.components.follower:AddLoyaltyTime( (TUNING.CATCOON_LOYALTY_PER_ITEM)*2.5 )
			
			v.components.locomotor.walkspeed = 4
			end
			
			local fx = SpawnPrefab("emote_fx")
			fx.Transform:SetPosition(v.Transform:GetWorldPosition())
			fx.Transform:SetScale(0.6, 0.6, 0.6)
			
			if v.components.combat.target and v.components.combat.target == caster then
				v.components.combat:SetTarget(nil)
			end
			
		elseif v.prefab == "catcoon" and caster:HasTag("monster") then
			if v.components.sleeper:IsAsleep() then
				v.components.sleeper:WakeUp()
				end
			if not v.sg:HasStateTag("busy") then 
				v:FacePoint(caster.Transform:GetWorldPosition())
				v.sg:GoToState("hiss")
				end
			local fx = SpawnPrefab("emote_fx")
			fx.Transform:SetPosition(v.Transform:GetWorldPosition())
			fx.Transform:SetScale(0.6, 0.6, 0.6)
			v.components.combat:SuggestTarget(caster)
        end
    end
    return true
end

    inst:AddComponent("inspectable")
    
	inst:AddComponent("sanityaura")
	inst.components.sanityaura.aura = TUNING.SANITYAURA_TINY*0.16
	inst.components.sanityaura:GetAura("tula")
	
    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.atlasname = "images/inventoryimages/catcoonstaff.xml"
    inst.components.inventoryitem.imagename = "catcoonstaff"
    
    inst:AddComponent("equippable")
    inst.components.equippable:SetOnEquip(onequip)
    inst.components.equippable:SetOnUnequip(onunequip)

	inst:AddComponent("spellcaster")
    inst.components.spellcaster:SetSpellFn(catcoonstaff)
    inst.components.spellcaster.canuseontargets = false
	inst.components.spellcaster.canusefrominventory = true
	inst.components.spellcaster.canuseonpoint = true
    inst:AddTag("nopunch")
	
	inst:AddComponent("finiteuses")
    inst.components.finiteuses:SetMaxUses(10)
    inst.components.finiteuses:SetUses(10)
    inst.components.finiteuses:SetOnFinished( onfinished )
    
    return inst
end

STRINGS.NAMES.CATCOONSTAFF = "Cat Staff"
STRINGS.RECIPE_DESC.CATCOONSTAFF = "Rule them all!"

STRINGS.CHARACTERS.GENERIC.DESCRIBE.CATCOONSTAFF = "I think this has to do something with cats."

STRINGS.CHARACTERS.WILLOW.DESCRIBE.CATCOONSTAFF = "Soft fur on a magic wand!"

STRINGS.CHARACTERS.WOLFGANG.DESCRIBE.CATCOONSTAFF = "Is cat magic."

STRINGS.CHARACTERS.WENDY.DESCRIBE.CATCOONSTAFF = "I will lead cats to their death."

STRINGS.CHARACTERS.WX78.DESCRIBE.CATCOONSTAFF = "CATCOON BRAINWAVE EMITTER"

STRINGS.CHARACTERS.WICKERBOTTOM.DESCRIBE.CATCOONSTAFF = "It appears to make wildcats somewhat obedient."

STRINGS.CHARACTERS.WOODIE.DESCRIBE.CATCOONSTAFF = "This thing will make those pests more useful."

STRINGS.CHARACTERS.WAXWELL.DESCRIBE.CATCOONSTAFF = "They'll be still vermin, just obedient."

STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.CATCOONSTAFF = "It's cat magic!"

STRINGS.CHARACTERS.WEBBER.DESCRIBE.CATCOONSTAFF = "We won't make much use of it, I feel."

return Prefab("common/inventory/catcoonstaff", init, assets)